==> mgb-0.5.3-de.zip: mgb-0.5.3-de/language/lang_admin.php <==
<?php
	// MGB v.null.fnf (C) by Jrgen Grneisl
         //
         // This Guestbook is licensed under GNU GPL. Feel free to use, copy, share or modify it. :)
         //
         // released on 27th of October 2005

//lang_admin.php - Sprachvariablen fr die Administration

	//////////////////
	// DEUTSCH v1.0 //
	//////////////////

// Allgemeine Variablen

$lang['back_to_gb']	= "Zurck zum Gstebuch";
$lang['back']		= "zurck";


// Fehlermeldungen

$lang['failure']		= "Fehler";
$lang['not_logged_in']	= "Sie sind nicht angemeldet. Bitte melden Sie sich<br>zuerst durch Eingabe ihres Passwortes an.";
$lang['changed_pw']	= "Sie haben das Passwort ge&auml;ndert. Es ist erforderlich da&szlig; Sie sich erneut in die Administration einloggen.";


// passwort.php

$lang['createpassword_title']		= "Passwort erstellen";
$lang['createpassword_firstcall']	= "Dies scheint ihr erster Aufruf der Administration zu sein. Bitte erstellen Sie jetzt ein Passwort. Merken Sie sich dieses Passwort gut, denn es kann nicht wieder entschl&uuml;sselt werden.";
$lang['adminfailure']			= "Fehlgeschlagener Administrationszugriffsversuch.<br>Der Admin wurde benachrichtigt.";
$lang['password']			= "Passwort";
$lang['wrong_password']			= "Das Passwort ist falsch";
$lang['wait']				= "Einen Moment bitte...";
$lang['password_mail_title']		= "Fehlgeschlagener Administrationszugriff";
$lang['password_mail_message']		= "Es wurde versucht auf die Administration des G&auml;stebuches auf ".$settings['hpname']." zuzugreifen.";
$lang['password_mail_date']		= "Datum";
$lang['password_mail_time']		= "Uhrzeit";
$lang['password_mail_time_des']		= " Uhr";
$lang['password_mail_givenpw']		= "Eingegebenes Passwort";


// admin.php

$lang['navi_settings']		= "Einstellungen";
$lang['navi_activate']		= "Eintr&auml;ge freischalten";
$lang['navi_deactivate']		= "Eintrge deaktivieren";
$lang['navi_delete']		= "Eintrge lschen";
$lang['navi_comment']		= "Eintrge kommentieren";
$lang['navi_onlinehelp']		= "Onlinehandbuch";
$lang['navi_back']		= "zurck";


// editsettings.php

$lang['save_settings']		= "Einstellungen &auml;ndern";
$lang['title_first']		= "Allgemeine Einstellungen";
$lang['title_second']		= "Texte";
$lang['title_third']		= "Tabellen";
$lang['title_fourth']		= "Hyperlinks";
$lang['title_fifth']		= "Eingabefelder / Schaltflchen";
$lang['title_sixth']		= "Interaktion";
$lang['title_seventh']		= "Sicherheit";

$lang['no']	= "Nein";
$lang['yes']	= "Ja";

$lang['normal']	= "Normal"; // fr Hyperlinks
$lang['none']	= "Keine Unterstreichung"; // fr Hyperlinks
$lang['overline']= "berstrichen"; // fr Hyperlinks

$lang['1']  = "Name der Homepage";
$lang['2']  = "Adresse der Homepage";
$lang['3']  = "Pfad zum Gstebuch";
$lang['4']  = "eMail des Admins";
$lang['5']  = "Metatag: Autor";
$lang['6']  = "Metatag: Schlsselwrter";
$lang['7']  = "Hintergrundfarbe der Seite";
$lang['8']  = "Alternativ: Pfad zu Hintergrundbild";
$lang['9']  = "ffne Administration in einem neuen Fenster";
$lang['10'] = "eMail Spamschutz aktiv?";
$lang['11'] = "Smilies erlauben?";
$lang['12'] = "Zeige Gstebuchinformationen an";
$lang['13'] = "Quake Farbcodes auch fr Nachricht erlauben?";
$lang['14'] = "Wortzensur (Durch Kommas getrennt eingeben)";
$lang['15'] = "berschrift";
$lang['16'] = "Schriftgre der berschrift";
$lang['17'] = "Farbe der berschrift";
$lang['18'] = "Allgemeine Schriftart";
$lang['19'] = "Schriftgre";
$lang['20'] = "Schriftfarbe";
$lang['21'] = "Schriftfarbe fr Fehlermeldungen";
$lang['22'] = "Schriftfarbe fr Name in Eintrgen";
$lang['23'] = "Rahmentabelle: Titelhintergrundfarbe";
$lang['24'] = "Rahmentabelle: Hintergrundfarbe";
$lang['25'] = "Rahmentabelle: Randfarbe";
$lang['26'] = "Rahmentabelle: Breite in Pixel";
$lang['27'] = "Rahmentabelle: Breite des Randes";
$lang['28'] = "Eintragstabelle: Hintergrundfarbe";
$lang['29'] = "Eintragstabelle: Randfarbe";
$lang['30'] = "Eintragstabelle: Breite in %";
$lang['31'] = "Eintragstabelle: Breite des Randes";
$lang['32'] = "Linkfarbe";
$lang['33'] = "Aktiver Link";
$lang['34'] = "Besuchter Link";
$lang['35'] = "Linkhoverfarbe";
$lang['36'] = "Linkstil";
$lang['37'] = "Hintergrundfarbe";
$lang['38'] = "Randfarbe";
$lang['39'] = "Textfarbe";
$lang['40'] = "Breite des Randes";
$lang['41'] = "Benutzer: Dankesmail?";
$lang['42'] = "Benutzer: Benachrichtigung bei Freischaltung?";
$lang['43'] = "Bei Eintrag benachrichtigen?";
$lang['44'] = "Neues Passwort";
$lang['45'] = "(leer lassen falls nicht gewnscht)";
$lang['46'] = "Fehlerhaften Adminzugriff per eMail melden?";
$lang['47'] = "Benachrichtigung nach";
$lang['48'] = "fehlerhaften Versuchen";


// activate.php, deactivate.php, delete.php, comment.php

$lang['email_subject']		= "Ihr Eintrag auf ".$settings['hpname']; // $settings['hpname'] = Name der Homepage
$lang['email_activate_greetz']	= "Hallo";
$lang['email_activate_message']  = "Ihr Eintrag wurde soeben freigeschaltet, und Sie knnen Ihn sich jetzt hier ansehen:";
$lang['email_comment_message']   = "Zu Ihrem Eintrag wurde soeben ein Kommentar verfasst. Zum Kommentar:";
$lang['activate_entry']		= "Diesen Eintrag aktivieren";
$lang['deactivate_entry']	= "Diesen Eintrag deaktivieren";
$lang['delete_entry']		= "Diesen Eintrag l&ouml;schen";
$lang['active_entries']		= "aktive Eintr&auml;ge";
$lang['deactivated_entries']	= "deaktivierte Eintr&auml;ge";
$lang['legend_active']		= "Dieser Eintrag ist aktiv";
$lang['legend_inactive']		= "Dieser Eintrag ist inaktiv";
$lang['comment_this_entry']	= "Diesen Eintrag kommentieren";
$lang['before_commentcount']	= "davon";
$lang['after_commentcount']	= "mit Kommentar";
$lang['comment_button']		= "Kommentar ndern";
$lang['comment_title']		= "ndern Sie Ihren Kommentar";
$lang['comment_success']		= "Ihr Kommentar wurde erfolgreich eingetragen.";
$lang['comment_failure']		= "Es ist ein Fehler aufgetreten. Ihr Kommentar konnte nicht eingetragen werden!";
$lang['comment_notify_user']	= "Der Benutzer wurde wie von ihm gewnscht per mail benachrichtigt.";

?>

==> mgb-0.5.4.3-de.zip: mgb-0.5.4.3-de/language/lang_admin.php <==
<?php
	/*
	MGB 0.5.4.3
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

//lang_admin.php - Sprachvariablen fr die Administration

////////////////////
// DEUTSCH v1.0.2 //
////////////////////

// Allgemeine Variablen

$lang['back_to_gb']	= "Zurck zum Gstebuch";
$lang['back']		= "zurck";


// Fehlermeldungen

$lang['failure']		= "Fehler";
$lang['not_logged_in']	= "Sie sind nicht angemeldet. Bitte melden Sie sich<br>zuerst durch Eingabe ihres Passwortes an.";
$lang['changed_pw']	= "Sie haben das Passwort ge&auml;ndert. Es ist erforderlich da&szlig; Sie sich erneut in die Administration einloggen.";


// passwort.php

$lang['createpassword_title']		= "Passwort erstellen";
$lang['createpassword_firstcall']	= "Dies scheint ihr erster Aufruf der Administration zu sein. Bitte erstellen Sie jetzt ein Passwort. Merken Sie sich dieses Passwort gut, denn es kann nicht wieder entschl&uuml;sselt werden.";
$lang['adminfailure']			= "Fehlgeschlagener Administrationszugriffsversuch.<br>Der Admin wurde benachrichtigt.";
$lang['password']			= "Passwort";
$lang['wrong_password']			= "Das Passwort ist falsch";
$lang['wait']				= "Einen Moment bitte...";
$lang['password_mail_title']		= "Fehlgeschlagener Administrationszugriff";
$lang['password_mail_message']		= "Es wurde versucht auf die Administration des G&auml;stebuches auf ".$settings['hpname']." zuzugreifen.";
$lang['password_mail_date']		= "Datum";
$lang['password_mail_time']		= "Uhrzeit";
$lang['password_mail_time_des']		= " Uhr";
$lang['password_mail_givenpw']		= "Eingegebenes Passwort";


// admin.php

$lang['navi_settings']		= "Konfiguration";
$lang['navi_activate']		= "Eintr&auml;ge freischalten";
$lang['navi_deactivate']		= "Eintrge deaktivieren";
$lang['navi_delete']		= "Eintrge lschen";
$lang['navi_comment']		= "Eintrge kommentieren";
$lang['navi_onlinehelp']		= "Onlinehandbuch";
$lang['navi_back']		= "zurck";


// editsettings.php

$lang['save_settings']		= "Einstellungen &auml;ndern";
$lang['title_first']		= "Allgemeine Einstellungen";
$lang['title_second']		= "Texte";
$lang['title_third']		= "Tabellen";
$lang['title_fourth']		= "Hyperlinks";
$lang['title_fifth']		= "Eingabefelder / Schaltflchen";
$lang['title_sixth']		= "Interaktion";
$lang['title_seventh']		= "Sicherheit";

$lang['no']	= "Nein";
$lang['yes']	= "Ja";

$lang['normal']	= "Normal"; // fr Hyperlinks
$lang['none']	= "Keine Unterstreichung"; // fr Hyperlinks
$lang['overline']= "berstrichen"; // fr Hyperlinks

$lang['1']  = "Name der Homepage";
$lang['2']  = "Adresse der Homepage";
$lang['3']  = "Pfad zum Gstebuch";
$lang['4']  = "eMail des Admins";
$lang['5']  = "Metatag: Autor";
$lang['6']  = "Metatag: Schlsselwrter";
$lang['7']  = "Hintergrundfarbe der Seite";
$lang['8']  = "Alternativ: Pfad zu Hintergrundbild";
$lang['9']  = "ffne Administration in einem neuen Fenster";
$lang['10'] = "eMail Spamschutz aktiv?";
$lang['11'] = "Smilies erlauben?";
$lang['12'] = "Zeige Gstebuchinformationen an";
$lang['13'] = "Quake Farbcodes auch fr Nachricht erlauben?";
$lang['14'] = "Wortzensur (Durch Kommas getrennt eingeben)";
$lang['15'] = "berschrift";
$lang['16'] = "Schriftgre der berschrift";
$lang['17'] = "Farbe der berschrift";
$lang['18'] = "Allgemeine Schriftart";
$lang['19'] = "Schriftgre";
$lang['20'] = "Schriftfarbe";
$lang['21'] = "Schriftfarbe fr Fehlermeldungen";
$lang['22'] = "Schriftfarbe fr Name in Eintrgen";
$lang['23'] = "Rahmentabelle: Titelhintergrundfarbe";
$lang['24'] = "Rahmentabelle: Hintergrundfarbe";
$lang['25'] = "Rahmentabelle: Randfarbe";
$lang['26'] = "Rahmentabelle: Breite in Pixel";
$lang['27'] = "Rahmentabelle: Breite des Randes";
$lang['28'] = "Eintragstabelle: Hintergrundfarbe";
$lang['29'] = "Eintragstabelle: Randfarbe";
$lang['30'] = "Eintragstabelle: Breite in %";
$lang['31'] = "Eintragstabelle: Breite des Randes";
$lang['32'] = "Linkfarbe";
$lang['33'] = "Aktiver Link";
$lang['34'] = "Besuchter Link";
$lang['35'] = "Linkhoverfarbe";
$lang['36'] = "Linkstil";
$lang['37'] = "Hintergrundfarbe";
$lang['38'] = "Randfarbe";
$lang['39'] = "Textfarbe";
$lang['40'] = "Breite des Randes";
$lang['41'] = "Benutzer: Dankesmail?";
$lang['42'] = "Benutzer: Benachrichtigung bei Freischaltung?";
$lang['43'] = "Bei Eintrag benachrichtigen?";
$lang['44'] = "Neues Passwort";
$lang['45'] = "(leer lassen falls nicht gewnscht)";
$lang['46'] = "Fehlerhaften Adminzugriff per eMail melden?";
$lang['47'] = "Benachrichtigung nach";
$lang['48'] = "fehlerhaften Versuchen";
$lang['49'] = "Moderiertes Gstebuch?";
$lang['50'] = "BBCode erlauben?";


// activate.php, deactivate.php, delete.php, comment.php

$lang['email_subject']		= "Ihr Eintrag auf ".$settings['hpname']; // $settings['hpname'] = Name der Homepage
$lang['email_activate_greetz']	= "Hallo";
$lang['email_activate_message']  = "Ihr Eintrag wurde soeben freigeschaltet, und Sie knnen Ihn sich jetzt hier ansehen:";
$lang['email_comment_message']   = "Zu Ihrem Eintrag wurde soeben ein Kommentar verfasst. Zum Kommentar:";
$lang['activate_entry']		= "Diesen Eintrag aktivieren";
$lang['deactivate_entry']	= "Diesen Eintrag deaktivieren";
$lang['delete_entry']		= "Diesen Eintrag l&ouml;schen";
$lang['active_entries']		= "aktive Eintr&auml;ge";
$lang['deactivated_entries']	= "deaktivierte Eintr&auml;ge";
$lang['legend_active']		= "Dieser Eintrag ist aktiv";
$lang['legend_inactive']		= "Dieser Eintrag ist inaktiv";
$lang['comment_this_entry']	= "Diesen Eintrag kommentieren";
$lang['before_commentcount']	= "davon";
$lang['after_commentcount']	= "mit Kommentar";
$lang['comment_button']		= "Kommentar ndern";
$lang['comment_title']		= "ndern Sie Ihren Kommentar";
$lang['comment_success']		= "Ihr Kommentar wurde erfolgreich eingetragen.";
$lang['comment_failure']		= "Es ist ein Fehler aufgetreten. Ihr Kommentar konnte nicht eingetragen werden!";
$lang['comment_notify_user']	= "Der Benutzer wurde wie von ihm gewnscht per mail benachrichtigt.";

?>
